pub enum PairingEvent {
Searching,
DeviceFound(DiscoveredDevice),
Passkey(PasskeyMethod),
Paired {
slot: u8,
},
Failed(PairingError),
}Expand description
Events streamed out of a pairing session.
Variants
Searching
Discovery (Bolt) or the pairing lock (Unifying) is now open.
DeviceFound(DiscoveredDevice)
Bolt only: a nearby unpaired device was discovered.
Passkey(PasskeyMethod)
Bolt only: the device asks the user to enter a passkey to authenticate.
Paired
A device was paired and assigned a receiver slot.
Failed(PairingError)
The flow ended without pairing a device.